pub fn set(preferences: Preferences)Expand description
Update the values of the global preferences for the current process. This also notifies the
observers previously added using add_observer.
pub fn set(preferences: Preferences)Update the values of the global preferences for the current process. This also notifies the
observers previously added using add_observer.