pub trait PreferencesObserver: Send + Sync {
// Provided method
fn prefs_changed(&self, _changes: &[(&'static str, PrefValue)]) { ... }
}Expand description
A trait to be implemented by components that wish to be notified about runtime changes to the global preferences for the current process.
Provided Methods
Sourcefn prefs_changed(&self, _changes: &[(&'static str, PrefValue)])
fn prefs_changed(&self, _changes: &[(&'static str, PrefValue)])
This method is called when the global preferences have been updated. The argument to the method is an array of tuples where the first component is the name of the preference and the second component is the new value of the preference.